.. currentmodule:: {{ info['modulename'] }}

This document has been autogenerated by taurusdoc for test purposes.
Any modifications will be lost.
It may differ from the final documentation.

:class:`{{ classname }}`
{{ '=' * (classname|count + 9 ) }}

.. autoclass:: {{ classname }}
    :members:
    :undoc-members:
    :show-inheritance:
